[![Publish](https://github.com/byte-motion/ocellus-python-client/actions/workflows/publish.yaml/badge.svg)](https://github.com/byte-motion/ocellus-python-client/actions/workflows/publish.yaml)
# ocellus-python-client
Autogenerated python client from [byte-motion/ProtobufDefs](https://github.com/byte-motion/ProtobufDefs/)

# Installation
```shell
pip install ocellus
```

# Build and Deploy Manually
```shell
$ python3 setup.py sdist bdist_wheel
$ twine check dist/*
$ twine upload dist/*
```

# Example and Documentation
Examples can be found in the [examples folder](./examples/)\
More documentation can be found here: https://docs.ocellus.io/remote-python-module-example/